/*
 * Copyright (c) 2008-2013 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */

/*global NX, Nexus, Sonatype, Ext*/

NX.define('Nexus.ssl.certificate.CertificateDetailsView', {
  extend : 'Ext.Panel',

  statics : {
    NO_DETAIL : {
      xtype : 'panel',
      html : '<p style="margin: 15px">Select a certificate to display its details.</p>'
    },
    COULD_NOT_RETRIEVE : {
      xtype : 'panel',
      html : '<p style="margin: 15px; color: red;">Could not retrieve the certificate.</p>'
    },
    RETRIEVE_ERROR : function(errorMessage) {
      return {
        xtype : 'panel',
        frame : true,
        html : '<p style="margin: 15px; color: red;">Could not retrieve the certificate:<br/>'
              + errorMessage + '</p>'
      };
    }
  },

  xtype : 'certificate-details',

  initComponent : function() {
    var self = this, subject, issuer, validity;

    self.data = self.certificate;

    self.defaults = {
      readonly : true
    };

    self.layout = 'form';

    if ( self.initialConfig.frame === undefined) {
      self.frame = true;
    }

    self.autoScroll = true;

    subject = {
      xtype : 'fieldset',
      title : 'Subject',
      items : [
        {
          xtype : 'displayfield',
          fieldLabel : 'Common Name',
          value : self.data.subjectCommonName
        },
        {
          xtype : 'displayfield',
          fieldLabel : 'Organisation',
          value : self.data.subjectOrganization
        },
        {
          xtype : 'displayfield',
          fieldLabel : 'Unit',
          value : self.data.subjectOrganizationalUnit
        }
      ]
    };
    issuer = {
          xtype : 'fieldset',
          title : 'Issuer',
          items : [
            {
              xtype : 'displayfield',
              fieldLabel : 'Common Name',
              value : self.data.issuerCommonName
            },
            {
              xtype : 'displayfield',
              fieldLabel : 'Organisation',
              value : self.data.issuerOrganization
            },
            {
              xtype : 'displayfield',
              fieldLabel : 'Unit',
              value : self.data.issuerOrganizationalUnit
            }
          ]
        };
    validity = {
      xtype : 'fieldset',
      title : 'Certificate',
      items : [
        {
          xtype : 'timestampDisplayField',
          fieldLabel : 'Issued On',
          value : self.data.issuedOn
        },
        {
          xtype : 'timestampDisplayField',
          fieldLabel : 'Valid until',
          value : self.data.expiresOn
        },
        {
          xtype : 'displayfield',
          fieldLabel : 'Fingerprint',
          value : self.data.fingerprint
        }
      ]
    };

    self.items = [
      subject,
      issuer,
      validity
    ];

    self.constructor.superclass.initComponent.apply(self, arguments);
  }
})
;
