/*
 * Copyright (c) 2008-2013 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global NX,Ext,Sonatype,Nexus*/
NX.define('Sonatype.repoServer.LdapConfigurationConnection', {
  extend : 'Ext.Panel',
  constructor : function(cfg) {
    var config = cfg || {};
    Ext.apply(this, config, {});

    var protocolStore = new Ext.data.SimpleStore({
      fields : ['value'],
      data : [
        ['ldap'],
        ['ldaps']
      ]
    });

    var authenticationMethodStore = new Ext.data.SimpleStore({
      fields : ['value', 'display'],
      data : [
        ['simple', 'Simple Authentication'],
        ['none', 'Anonymous Authentication'],
        ['DIGEST-MD5', 'DIGEST-MD5'],
        ['CRAM-MD5', 'CRAM-MD5']
      ]
    });

    Sonatype.repoServer.LdapConfigurationConnection.superclass.constructor.call(this, {
      items : [
        {
          xtype : 'fieldset',
          title : 'Connection',
          items : [
            {
              xtype : 'textfield',
              fieldLabel : 'Name',
              helpText : 'The name of the LDAP Server.',
              name : 'name',
              width : this.fieldWidth,
              allowBlank : false,
              itemCls : 'required-field'
            },
            {
              xtype : 'combo',
              fieldLabel : 'Protocol',
              itemCls : 'required-field',
              helpText : 'Use plain text (ldap://) or secure (ldaps://) connection.',
              name : 'connectionInfo.protocol',
              width : this.fieldWidth,
              store : protocolStore,
              valueField : 'value',
              displayField : 'value',
              editable : false,
              forceSelection : true,
              mode : 'local',
              triggerAction : 'all',
              emptyText : 'Select...',
              selectOnFocus : true,
              allowBlank : false,
              listeners : {
                select : {
                  fn : function(combo, record, index) {
                    var newValue = combo.getValue();
                    var port = this.find('name', 'connectionInfo.port')[0];
                    var portValue = port.getRawValue();
                    if (newValue == 'ldap' && (portValue == 636 || portValue == 0)) {
                      port.setValue(389);
                    }
                    else if (newValue == 'ldaps' && (portValue == 389 || portValue == 0)) {
                      port.setValue(636);
                    }
                  },
                  scope : this
                }
              }
            },
            {
              xtype : 'textfield',
              fieldLabel : 'Hostname',
              helpText : 'The host name of the LDAP server.',
              name : 'connectionInfo.host',
              width : this.fieldWidth,
              allowBlank : false,
              itemCls : 'required-field'
            },
            {
              xtype : 'numberfield',
              fieldLabel : 'Port',
              helpText : 'The port the LDAP server is listening on (ldap - 389, ldaps - 636).',
              name : 'connectionInfo.port',
              width : this.fieldWidth,
              allowBlank : false,
              itemCls : 'required-field'
            },
            {
              xtype : 'textfield',
              fieldLabel : 'Search Base',
              helpText : 'LDAP location to be added to the connection URL, e.g. "dc=sonatype,dc=com".',
              name : 'connectionInfo.searchBase',
              width : this.fieldWidth,
              itemCls : 'required-field',
              allowBlank : false
            }
          ]
        },
        {
          xtype : 'fieldset',
          labelWidth : 188,
          checkboxToggle : false,
          title : 'Authentication',
          collapsible : true,
          autoHeight : true,
          items : [
            {
              xtype : 'combo',
              fieldLabel : 'Authentication Method',
              itemCls : 'required-field',
              helpText : 'Authentication method.',
              name : 'connectionInfo.authScheme',
              width : this.fieldWidth,
              store : authenticationMethodStore,
              valueField : 'value',
              displayField : 'display',
              editable : false,
              forceSelection : true,
              mode : 'local',
              triggerAction : 'all',
              emptyText : 'Select...',
              selectOnFocus : true,
              allowBlank : false,
              listeners : {
                select : {
                  fn : this.authenticationMethodSelectHandler,
                  scope : this
                }
              }
            },
            {
              xtype : 'textfield',
              fieldLabel : 'SASL Realm',
              helpText : 'The SASL realm to bind to, e.g. "mydomain.com".',
              name : 'connectionInfo.realm',
              width : this.fieldWidth,
              allowBlank : true
            },
            {
              xtype : 'textfield',
              fieldLabel : 'Username',
              helpText : 'The username or DN to bind with. If simple authentication is used, this has to be a fully qualified user name.',
              name : 'connectionInfo.systemUsername',
              width : this.fieldWidth,
              allowBlank : true
            },
            {
              xtype : 'textfield',
              fieldLabel : 'Password',
              inputType : 'password',
              helpText : 'The password to bind with.',
              name : 'connectionInfo.systemPassword',
              width : this.fieldWidth,
              allowBlank : true
            }
          ]
        },
        {
          xtype : 'fieldset',
          checkboxToggle : false,
          title : 'Timeouts',
          labelWidth : 188,
          collapsible : true,
          autoHeight : true,
          items : [
            {
              xtype : 'numberfield',
              fieldLabel : 'Connection Timeout',
              helpText : 'The number of seconds to wait before timeout on connection to LDAP Server.',
              name : 'connectionInfo.connectionTimeout',
              width : this.fieldWidth,
              allowBlank : false,
              itemCls : 'required-field'
            },
            {
              xtype : 'numberfield',
              fieldLabel : 'Retry Delay',
              helpText : 'The number of seconds to wait before retrying a request to the LDAP Server.',
              name : 'connectionInfo.connectionRetryDelay',
              width : this.fieldWidth,
              allowBlank : false,
              itemCls : 'required-field'
            }
          ]
        },
        {
          xtype : 'fieldset',
          checkboxToggle : true,
          title : 'Cache',
          labelWidth : 188,
          autoHeight : true,
          listeners : {
            'expand' : {
              fn : function(panel) {
                this.ldapConfigurationContainer.expandHandler(panel);
              },
              scope : this
            },
            'collapse' : {
              fn : function(panel) {
                this.find('name', 'connectionInfo.cacheTimeout')[0].setValue(0);
                this.ldapConfigurationContainer.collapseHandler(panel);
              },
              scope : this,
              delay : 100
            }
          },
          items : [
            {
              xtype : 'numberfield',
              fieldLabel : 'Cache Duration',
              helpText : 'The number of seconds to keep items in the cache.',
              name : 'connectionInfo.cacheTimeout',
              width : this.fieldWidth,
              allowBlank : false,
              itemCls : 'required-field'
            }
          ]
        }
      ],
      listeners : {
        afterlayout : {
          fn : function() {
            this.isLoaded = true;
          },
          scope : this
        }
      }
    });
  },

  postLoad : function() {
    if (this.ldapConfigurationContainer.isNew) {
      this.find('name', 'connectionInfo.connectionTimeout')[0].setValue(30);
      this.find('name', 'connectionInfo.connectionRetryDelay')[0].setValue(300);
      this.find('name', 'connectionInfo.cacheTimeout')[0].setValue(600);
    }
    else {
      this.authenticationMethodSelectHandler(this.find('name', 'connectionInfo.authScheme')[0]);

      var cacheDur = this.find('name', 'connectionInfo.cacheTimeout')[0];
      if (cacheDur.getValue() > 0) {
        cacheDur.ownerCt.expand();
      }
      else {
        cacheDur.ownerCt.collapse();
      }
    }
  },
  authenticationMethodSelectHandler : function(combo, record, index) {
    if (combo.getValue() == 'simple') {
      this.find('name', 'connectionInfo.realm')[0].disable();
      this.find('name', 'connectionInfo.systemUsername')[0].enable();
      this.find('name', 'connectionInfo.systemPassword')[0].enable();
    }
    else if (combo.getValue() == 'none') {
      this.find('name', 'connectionInfo.realm')[0].disable();
      this.find('name', 'connectionInfo.systemUsername')[0].disable();
      this.find('name', 'connectionInfo.systemUsername')[0].setValue('');
      this.find('name', 'connectionInfo.systemPassword')[0].disable();
      this.find('name', 'connectionInfo.systemPassword')[0].setValue('');
    }
    else if (combo.getValue() == 'DIGEST-MD5') {
      this.find('name', 'connectionInfo.realm')[0].enable();
      this.find('name', 'connectionInfo.systemUsername')[0].enable();
      this.find('name', 'connectionInfo.systemPassword')[0].enable();
    }
    else if (combo.getValue() == 'CRAM-MD5') {
      this.find('name', 'connectionInfo.realm')[0].enable();
      this.find('name', 'connectionInfo.systemUsername')[0].enable();
      this.find('name', 'connectionInfo.systemPassword')[0].enable();
    }
  },
  handleButtons : function() {
    this.ldapConfigurationContainer.formPanel.buttons[0].show();
    this.ldapConfigurationContainer.formPanel.buttons[1].hide();
    this.ldapConfigurationContainer.formPanel.buttons[2].hide();
  },
  checkAuthentication : function() {
    var   params,
          ldapServerId = this.ldapConfigurationContainer.record.get('id'),
          isNew = this.ldapConfigurationContainer.isNew;
    if ( !isNew ) {
      params = {
        ldapServerId : ldapServerId
      };
    }

    Sonatype.MessageBox.wait('Checking LDAP Authentication...');
    Ext.Ajax.request({
      method : 'PUT',
      url : Sonatype.config.servicePath + '/ldap/test_auth',
      params : params,
      jsonData : {
        data : {
          protocol : this.find('name', 'connectionInfo.protocol')[0].getValue(),
          host : this.find('name', 'connectionInfo.host')[0].getValue(),
          port : this.find('name', 'connectionInfo.port')[0].getValue(),
          searchBase : this.find('name', 'connectionInfo.searchBase')[0].getValue(),
          authScheme : this.find('name', 'connectionInfo.authScheme')[0].getValue(),
          realm : this.find('name', 'connectionInfo.realm')[0].getValue(),
          systemUsername : this.find('name', 'connectionInfo.systemUsername')[0].getValue(),
          systemPassword : this.find('name', 'connectionInfo.systemPassword')[0].getValue(),
          connectionTimeout : this.find('name', 'connectionInfo.connectionTimeout')[0].getValue(),
          connectionRetryDelay : this.find('name', 'connectionInfo.connectionRetryDelay')[0].getValue(),
          cacheTimeout : this.find('name', 'connectionInfo.cacheTimeout')[0].getValue()
        }
      },
      callback : function(options, success, response) {
        if (success) {
          Sonatype.MessageBox.alert('Check Authentication',
                'LDAP connection and authentication test completed successfully.').setIcon(Sonatype.MessageBox.INFO);
        }
        else {
          Sonatype.utils.connectionError(response, 'LDAP connection and authentication test failed.', false, {
            hideErrorStatus : true,
            decodeErrorResponse : true
          });
        }
      }
    });
  }
});