/*
 * Copyright (c) 2008-2013 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global NX,Ext,Sonatype,Nexus*/
NX.define('Sonatype.repoServer.LdapConfigurationSSLCertificate', {
  extend : 'Nexus.ssl.AbstractCertificateTab',

  type : 'ldap',
  title : 'SSL',

  parseUrl : function(str) {
    if (!str) {
      return [];
    }

    var rx = /[^:]*:\/\/([^:\/]*)(:([0-9]*))?/,
          matches = str.match(rx);

    if (matches) {
      return [matches[1], matches[3]];
    }

    return [str];
  },

  setCertRequestParams : function() {
    var   self = this,
          hostParts = self.parseUrl(self.ldapConfigurationContainer.record.get('ldapUrl')),
          host = hostParts[0],
          port = hostParts[1] || 636;

    self.certRequestParams = {
      host : host,
      port : port,
      protocolHint : 'ldaps'
    };
  },

  initComponent : function() {
    var self = this;

    self.data = {
      id : self.ldapConfigurationContainer.record.get('id')
    };
    self.setCertRequestParams();

    self.constructor.superclass.initComponent.apply(self, arguments);
  },

  isSaved : function() {
    return !this.ldapConfigurationContainer.isNew;
  },

  loadSettings : function() {
    var self = this;

    if (!self.isSaved()) {
      return;
    }

    if (self.data.id !== self.ldapConfigurationContainer.record.get('id')) {
      self.data.id = self.ldapConfigurationContainer.record.get('id');
      self.setCertRequestParams();
    }

    self.constructor.superclass.loadSettings.apply(self, arguments);
  },

  hideButtons : function(panel, tab) {
    if (this !== tab) {
      Ext.each(this.ldapConfigurationContainer.formPanel.buttons, function(button) {
        button.show();
      });
    }
  },

  handleButtons : function() {
    var self = this;

    // tabPanel is not yet instantiated in initComponent
    // handleButtons is called for tabchange event, so we use this to add listeners
    // same function will not be registered twice, so this is safe
    self.ldapConfigurationContainer.tabPanel.on('beforetabchange', Ext.createDelegate(self.hideButtons, self));

    Ext.each(this.ldapConfigurationContainer.formPanel.buttons, function(button) {
      button.hide();
    });

    // EXTJSBUG box layout inside form layout will not request a height, and be rendered with height 0.
    // Force the real size here.
    this.items.get(0).setHeight(this.getHeight() - this.getFrameHeight());
  }
});