/*
 * Copyright (c) 2008-2013 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
Sonatype.repoServer.M2SettingsPanel = function(config) {
  var config = config || {};
  var defaultConfig = {
    title : 'Maven Settings'
  };
  Ext.apply(this, config, defaultConfig);

  var sp = Sonatype.lib.Permissions;

  var toolbar = [];

  Sonatype.repoServer.M2SettingsPanel.superclass.constructor.call(this, {
        addMenuInitEvent : 'templateAddMenuInit',
        deleteButton : sp.checkPermission('nexus:settingstemplates', sp.DELETE),
        rowClickEvent : 'templateViewInit',
        rowFocusChangedEvent : 'templateGridClicked',
        url : Sonatype.config.servicePath + '/templates/settings',
        dataAutoLoad : false,
        tabbedChildren : true,
        tbar : toolbar,
        dataSortInfo : {
          field : 'id',
          direction : 'asc'
        },

        columns : [{
              name : 'id',
              header : 'Template ID',
              width : 100
            }, {
              name : 'readonly',
              renderer : function(s) {
                return !s
              },
              header : 'User Managed',
              width : 100
            }, {
              name : 'resourceURI'
            }, {
              name : 'downloadURI',
              header : 'Template URL',
              width : 625,
              renderer : function(s) {
                return '<a href="' + s + '" onclick=\'return showSettingsXML(\"' + s + '\")\'>' + s + '</a>';
              },
              // renderer: function(s){return '<a href="' + s + ((s != null &&
              // (s.charAt(s.length)) == '/') ? '' : '/') +'" target="_blank">'
              // + s + '</a>';},
              menuDisabled : true
            }]
      });
  // need to set this so that the 'delete' button knows the right name to
  // display
  this.titleColumn = 'id';
  this.dataStore.load();

};

Ext.extend(Sonatype.repoServer.M2SettingsPanel, Sonatype.panels.GridViewer, {

});

Sonatype.Events.addListener('nexusNavigationInit', function(nexusPanel) {
      nexusPanel.add({
            enabled : Sonatype.lib.Permissions.checkPermission('nexus:settingstemplates', Sonatype.lib.Permissions.READ),
            sectionId : 'st-nexus-enterprise',
            title : 'Maven Settings',
            tabId : 'm2-settings-templates',
            tabCode : Sonatype.repoServer.M2SettingsPanel
          });
    });

Sonatype.Events.addListener('templateGridClicked', function(cardPanel, rec, gridPanel) {

      if (gridPanel.toolbarDeleteButton)
      {
        if (rec.data.readonly)
        {
          gridPanel.toolbarDeleteButton.disable();
        }
        else
        {
          gridPanel.toolbarDeleteButton.enable();
        }
      }
    });

Sonatype.Events.addListener('templateAddMenuInit', function(menu) {
      var sp = Sonatype.lib.Permissions;

      if (sp.checkPermission('nexus:settingstemplates', sp.CREATE))
      {
        var createNewTemplateFunc = function(container, rec, item, e) {
          rec.beginEdit();
          rec.set('resourceURI', 'new');
          rec.set('id', '');
          rec.set('settingsXmlText', '');
          rec.commit();
          rec.endEdit();
        };

        menu.add(['-', {
              text : 'Settings Template',
              autoCreateNewRecord : true,
              handler : createNewTemplateFunc
            }]);
      }
    });

function showSettingsXML(url) {
  // alert( url );
  new Sonatype.repoServer.XMLPopupViewer({
        hostPanel : this,
        title : 'settings.xml',
        xmlUrl : url
      }).show();

  return false;
}
